@@ -1,4 +1,4 @@
-VERSION='1.6.2'
+VERSION='1.7.0'
 
 from cx_Freeze import setup, Executable
 import os
@@ -74,7 +74,7 @@ def addicons():
     ]
 
     for i in icons:
-        addfile(os.path.join('share/icons/Adwaita/16x16/', i + '-symbolic.symbolic.png'))
+        addfile(os.path.join('share/icons/Adwaita/scalable/', i + '-symbolic.svg'))
 
 required_dlls = [
     'gtk-3-0',
@@ -95,6 +95,10 @@ for dll in required_dlls:
     fn = 'lib' + dll + '.dll'
     include_files.append((os.path.join(sys.prefix, 'bin', fn), fn))
 
+# zlib1 is first loaded by a DLL located in lib
+include_files.append((os.path.join(sys.prefix, 'bin', 'zlib1.dll'),
+                      os.path.join('lib', 'zlib1.dll'),))
+
 required_gi_namespaces = [
     "Gtk-3.0",
     "Gdk-3.0",
@@ -106,7 +110,8 @@ required_gi_namespaces = [
     "GdkPixbuf-2.0",
     "GModule-2.0",
     "Atk-1.0",
-    "Poppler-0.18"
+    "Poppler-0.18",
+    "HarfBuzz-0.0"
 ]
 
 for ns in required_gi_namespaces:
@@ -121,6 +126,8 @@ addicons()
 build_options = dict(
     packages=['gi', 'packaging', 'pikepdf'],
     excludes=['tkinter', 'test'],
+    # manually added to the lib folder
+    bin_excludes=['zlib1.dll'],
     include_files=include_files,
 )
 
